package ru.myitschool.work.ui.entrylist

import androidx.fragment.app.viewModels
import android.os.Bundle
import android.util.Log
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import dagger.hilt.android.AndroidEntryPoint
import ru.myitschool.work.R
import ru.myitschool.work.databinding.FragmentEntryListBinding
import ru.myitschool.work.databinding.FragmentLoginBinding
import ru.myitschool.work.ui.entrylist.adapter.AdapterEntryHistory
import ru.myitschool.work.ui.entrylist.adapter.EntryHistoryEntity
import ru.myitschool.work.ui.login.LoginDestination
import ru.myitschool.work.ui.login.LoginViewModel
import ru.myitschool.work.ui.profile.ProfileDestination
import ru.myitschool.work.ui.profile.ProfileViewModel
import ru.myitschool.work.utils.collectWhenStarted
@AndroidEntryPoint
class EntryListFragment : Fragment(R.layout.fragment_entry_list) {

    private var _binding: FragmentEntryListBinding? = null
    private val binding: FragmentEntryListBinding get() = _binding!!

    private val viewModel: EntryListViewModel by viewModels()

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentEntryListBinding.bind(view)
        initCallback()
        subscribe()
    }

    private fun initCallback() {
        binding.floatingActionButton2.setOnClickListener { viewModel.closeEntryList() }


        binding.recyclerView.adapter = AdapterEntryHistory(viewModel.getEntryList())
        binding.recyclerView.layoutManager = LinearLayoutManager(requireContext())
    }

    private fun subscribe() {
        viewModel.action.collectWhenStarted(this) { action ->
                when (action) {
                    is EntryListViewModel.Action.OpenProfile -> {
                        findNavController().navigate(ProfileDestination) {
                            popUpTo<ProfileDestination> { inclusive = true }
                        }
                    }
                }
            }
        }
    }